# Plug-in Joystick

Le plugin Joystick traite les entrées (inputs) qui proviennent des joysticks, incluant les trackballs et autres spécificités des manettes. En utilisant le module joystick de PyGame, le plugin JOYSTICK permet l'utilisation d'un joystick avec boutons, axes, trackballs et casques.

## Options and variables de réponse

Le Plugin JOYSTICK fonctionnent de manière similaire à l'item KEYBOARD_RESPONSE. Pour plus d'informations, voir l'aide sur le KEYBOARD_RESPONSE ou rendez-vous sur :

- <http://osdoc.cogsci.nl/3.2/manual/response/keyboard/>

## Nom des boutons

Un nombre différents de boutons, axes, trackballs et casques est disponible en fonction du type de joystick ou gamepad que vous utilisez. Veuillez regarder quel bouton correspond à quel numéro de bouton (ainsi que pour les axes, trackballs et casques).

Pour plus d'informations, rendez-vous sur :

- <http://osdoc.cogsci.nl/3.2/manual/response/joystick/>
